package application

import (
	"os"
	"path"
	"sirlab.de/go/knyt/game"
)

func (app Application) loadGames() error {
	dirName := path.Join(app.config.DataDir, "games")
	files, err := os.ReadDir(dirName)
	if err != nil {
		return err
	}

	for _, file := range files {
		id := file.Name()
		gameDirName := path.Join(dirName, id)
		gameFileName := path.Join(gameDirName, "game.json")
		gm, errGame := game.NewGameFromFile(id, gameFileName)
		if errGame != nil {
			return errGame
		}

		errStatement := app.loadQuotes(gm, gameDirName)
		if errStatement != nil {
			return errStatement
		}
		for _, usr := range app.users {
			if usr.GetGameId() == id {
				gm.AddPlayer(usr)
			}
		}
		app.loadGameState(gm, path.Join(gameDirName, "state.json"))

		go gm.StartEngine()

		app.addGame(gm)
	}

	return nil
}

func (app Application) addGame(gm *game.Game) {
	app.mu.Lock()
	defer app.mu.Unlock()

	app.games[gm.GetId()] = gm
}
