package user

import (
	"encoding/json"
	"fmt"
	"os"
	"path"
	"strings"
)

func NewUserFromFile(fileName string) (*User, error) {
	jsonBytes, err := os.ReadFile(fileName)
	if err != nil {
		return nil, err
	}

	// var usr User
	var userJson UserJson
	if err := json.Unmarshal(jsonBytes, &userJson); err != nil {
		return nil, fmt.Errorf("%s: %v\n", fileName, err)
	} else {
		_, fileNameShort := path.Split(fileName)
		id := strings.TrimSuffix(fileNameShort, ".json")
		return &User{
			id:       id,
			name:     userJson.Name,
			role:     userJson.Role,
			authcode: userJson.Authcode,
			gameId:   userJson.GameId,
		}, nil
	}
}

func (usr *User) GetId() string {
	usr.mu.Lock()
	defer usr.mu.Unlock()

	return usr.id
}

func (usr *User) GetAuthCode() string {
	usr.mu.Lock()
	defer usr.mu.Unlock()

	return usr.authcode
}

func (usr *User) GetName() string {
	usr.mu.Lock()
	defer usr.mu.Unlock()

	return usr.name
}

func (usr *User) GetRole() string {
	usr.mu.Lock()
	defer usr.mu.Unlock()

	return usr.role
}

func (usr *User) GetGameId() string {
	usr.mu.Lock()
	defer usr.mu.Unlock()

	return usr.gameId
}

func (usr *User) IsPlayer() bool {
	return true
}

func (usr *User) IsGamemaster() bool {
	usr.mu.Lock()
	defer usr.mu.Unlock()

	return usr.role == ROLE_GAMEMASTER || usr.role == ROLE_ADMIN
}

func (usr *User) IsAdmin() bool {
	usr.mu.Lock()
	defer usr.mu.Unlock()

	return usr.role == ROLE_ADMIN
}
